;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "git-modes" "1.4.8"
  "Major modes for editing Git configuration files."
  '((emacs  "26.1")
    (compat "30.1"))
  :url "https://github.com/magit/git-modes"
  :commit "c3faeeea1982786f78d8c38397dec0f078eaec84"
  :revdesc "v1.4.8-0-gc3faeeea1982"
  :keywords '("convenience" "vc" "git")
  :authors '(("Sebastian Wiesner" . "lunaryorn@gmail.com")
             ("Rüdiger Sonderfeld" . "ruediger@c-plusplus.net")
             ("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev")))
